@@ -25,8 +25,6 @@
 #define MSG_NOSIGNAL        0
 #endif
 
-static char *str_ptr = NULL;
-
 int swConnection_onSendfile(swConnection *conn, swBuffer_trunk *chunk)
 {
     int ret;
@@ -171,28 +169,21 @@ swString* swConnection_get_string_buffer(swConnection *conn)
     }
 }
 
+static char tmp_address[INET6_ADDRSTRLEN];
+
 char* swConnection_get_ip(swConnection *conn)
 {
     if (conn->socket_type == SW_SOCK_TCP)
     {
         return inet_ntoa(conn->info.addr.inet_v4.sin_addr);
     }
+    if (inet_ntop(AF_INET6, &conn->info.addr.inet_v6.sin6_addr, tmp_address, sizeof(tmp_address)) == NULL)
+    {
+        return NULL;
+    }
     else
     {
-        if (str_ptr)
-        {
-            free(str_ptr);
-        }
-        char tmp[INET6_ADDRSTRLEN];
-        if (inet_ntop(AF_INET6, &conn->info.addr.inet_v6.sin6_addr, tmp, sizeof(tmp)) == NULL)
-        {
-            return NULL;
-        }
-        else
-        {
-            str_ptr = strdup(tmp);
-            return str_ptr;
-        }
+        return tmp_address;
     }
 }
 
@@ -212,7 +203,7 @@ void swConnection_sendfile_destructor(swBuffer_trunk *chunk)
 {
     swTask_sendfile *task = chunk->store.ptr;
     close(task->fd);
-    sw_strdup_free(task->filename);
+    sw_free(task->filename);
     sw_free(task);
 }
 
@@ -236,12 +227,12 @@ int swConnection_sendfile(swConnection *conn, char *filename, off_t offset)
     }
     bzero(task, sizeof(swTask_sendfile));
 
-    task->filename = strdup(filename);
+    task->filename = sw_strdup(filename);
     int file_fd = open(filename, O_RDONLY);
     if (file_fd < 0)
     {
-        sw_strdup_free(task->filename);
-        free(task);
+        sw_free(task->filename);
+        sw_free(task);
         swSysError("open(%s) failed.", filename);
         return SW_ERR;
     }
