@@ -1042,6 +1042,8 @@ int swServer_tcp_close(swServer *serv, int fd, int reset)
     {
         conn->close_reset = 1;
     }
+    //server is initiative to close the connection
+    conn->close_actively = 1;
     int ret;
     if (!swIsWorker())
     {
@@ -1203,7 +1205,8 @@ int swserver_add_systemd_socket(swServer *serv)
         case AF_UNIX:
             ls->type = sock_type == SOCK_STREAM ? SW_SOCK_UNIX_STREAM : SW_SOCK_UNIX_DGRAM;
             ls->port = 0;
-            strncpy(ls->host, address.addr.un.sun_path, SW_HOST_MAXSIZE);
+            strncpy(ls->host, address.addr.un.sun_path, SW_HOST_MAXSIZE - 1);
+            ls->host[SW_HOST_MAXSIZE - 1] = 0;
             break;
         default:
             swWarn("Unknown socket type[%d].", sock_type);
@@ -1494,6 +1497,7 @@ static void swHeartbeatThread_loop(swThreadParam *param)
                 conn->close_force = 1;
                 conn->close_notify = 1;
                 conn->close_wait = 1;
+                conn->close_actively = 1;
 
                 if (serv->factory_mode != SW_MODE_PROCESS)
                 {
