@@ -228,8 +228,8 @@ typedef union
 typedef struct
 {
     mysql_field *columns;
-    uint16_t num_column;
-    uint16_t index_column;
+    ulong_t num_column;
+    ulong_t index_column;
     uint32_t num_row;
     uint8_t wait_recv;
     uint8_t response_type;
@@ -359,7 +359,7 @@ static sw_inline int mysql_decode_field(char *buf, int len, mysql_field *col)
     /**
      * string buffer
      */
-    char *_buffer = emalloc(len);
+    char *_buffer = (char*)emalloc(len);
     if (!_buffer)
     {
         return -SW_MYSQL_ERR_BAD_LCB;
@@ -501,7 +501,7 @@ static sw_inline int mysql_decode_field(char *buf, int len, mysql_field *col)
     i += 4;
 
     /* type */
-    col->type = (uchar) buf[i];
+    col->type = (enum mysql_field_types) (uchar)buf[i];
     i += 1;
 
     /* flags */
