@@ -76,7 +76,7 @@ static CPINLINE int swoole_string_new (size_t size, seriaString *str, zend_uchar
         php_error_docref (NULL TSRMLS_CC, E_ERROR, "malloc Error: %s [%d]", strerror (errno), errno);
     }
 
-    SBucketType real_type;
+    SBucketType real_type = {0};
     real_type.data_type = type;
     *(SBucketType*) (str->buffer + str->offset) = real_type;
     str->offset += sizeof (SBucketType);
@@ -607,7 +607,7 @@ static void swoole_serialize_arr (seriaString *buffer, zend_array *zvalue)
 
     ZEND_HASH_FOREACH_KEY_VAL (zvalue, index, key, data)
     {
-        SBucketType type;
+        SBucketType type= {0};
         type.data_type = Z_TYPE_P (data);
         //start point
         size_t p = buffer->offset;
